#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 primitive-unaligned
version:              0.1.1.2
visibility:           public
id:                   primitive-unaligned-0.1.1.2-AAVt6yMjaoc21MuEc7Y7Vy
key:                  primitive-unaligned-0.1.1.2-AAVt6yMjaoc21MuEc7Y7Vy
license:              BSD-3-Clause
copyright:            2019 Andrew Martin
maintainer:           Andrew Martin <andrew.thaddeus@gmail.com>
author:               Andrew Martin
homepage:             https://github.com/haskell-primitive/primitive-unaligned
synopsis:             Unaligned access to primitive arrays
description:
    Unaligned access to primitive arrays. The offsets are given in bytes rather than elements.

category:             Data
abi:                  f1635bedf6c225e11dc777dfb0691f38
exposed:              True
exposed-modules:      Data.Primitive.ByteArray.Unaligned
hidden-modules:       Data.Primitive.Unaligned.Mach
import-dirs:          /usr/lib/ghc-9.6.6/site-local/primitive-unaligned-0.1.1.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/primitive-unaligned-0.1.1.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/primitive-unaligned-0.1.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-primitive-unaligned
hs-libraries:         HSprimitive-unaligned-0.1.1.2-AAVt6yMjaoc21MuEc7Y7Vy
depends:
    base-4.18.2.1 primitive-0.9.1.0-G6koubL8eviAMsrrurXf06

haddock-interfaces:
    /usr/share/doc/haskell-primitive-unaligned/html/primitive-unaligned.haddock

haddock-html:         /usr/share/doc/haskell-primitive-unaligned/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

